==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/ja.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "自分で読み取り権限を削除することはできません。",
    "Team folders" : "チームフォルダー",
    "Admin configured folders shared with everyone in a team" : "チーム内の全員と共有する管理者設定のフォルダー",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理者が設定したフォルダをチーム全員で共有。\n\nフォルダは管理者設定の*チームフォルダ*から設定できます。\n\nフォルダが作成されると、管理者は1つまたは複数のチームにフォルダへのアクセス権を与え、書き込み/共有権限を制御し、フォルダのクォータを割り当てることができます。\nHub 10/Nextcloud 31では、管理者はチームの一員でなければチームフォルダーを割り当てることができません。",
    "Unset" : "設定を解除",
    "Denied (Inherited permission)" : "拒否（権限継承）",
    "Allowed (Inherited permission)" : "許可（権限継承）",
    "Denied" : "拒否",
    "Allowed" : "許可",
    "Access denied" : "アクセス拒否",
    "Access allowed" : "アクセス許可",
    "Inherit permission" : "権限継承",
    "Deny" : "拒否",
    "Allow" : "許可",
    "Group" : "グループ",
    "Team" : "チーム",
    "Team folder" : "チームフォルダー",
    "Read" : "読み込み",
    "Write" : "編集",
    "Create" : "作成",
    "Delete" : "削除",
    "Share" : "共有",
    "You" : "自分",
    "Remove access rule" : "アクセスルールを削除",
    "Add advanced permission rule" : "詳細な権限ルールを追加",
    "Select a user or group" : "ユーザーまたはグループを選択",
    "Open Team folder" : "チームフォルダを開く",
    "Permission denied. User does not have sufficient permissions." : "パーミッションが拒否されました。ユーザーには十分な権限がありません。",
    "Unexpected status from server" : "サーバーからの予期しないステータス",
    "List of Team folders." : "チームフォルダーのリスト",
    "No Team folders yet" : "チームフォルダーはまだありません",
    "Team folders will show up here" : "チームフォルダーはここに表示されます",
    "Add group" : "グループを追加",
    "Default" : "デフォルト",
    "Unlimited" : "無制限",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "\"{folderName}\" とその中のすべてのファイルを削除してもよろしいですか？この操作は元に戻せません。",
    "Delete \"{folderName}\"?" : "\"{folderName}\" を削除しますか?",
    "Team folder admin delegation" : "チームフォルダー管理者の委任",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloudではチームフォルダーの管理を管理者以外のユーザーに委任することができます。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "チームフォルダーの管理とAPI/RESTの使用を許可するグループを以下に指定します。",
    "They will have access to all Team folders." : "彼らはすべてのチームフォルダーにアクセスできます。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "チームフォルダーの管理とAPI/RESTのみ使用を許可するグループを以下に指定します。",
    "They will only have access to Team folders for which they have advanced permissions." : "委任された人はあらかじめ許可が与えられたチームフォルダーにだけアクセスできます。",
    "Group or team" : "グループまたはチーム",
    "Sort by number of groups or teams that have access to this folder" : "このフォルダーにアクセスできるグループまたはチームの数で並べ替える",
    "Sort by number of groups that have access to this folder" : "このフォルダーにアクセスできるグループの数で並べ替える",
    "Folder name" : "フォルダー名",
    "Quota" : "クオータ",
    "Advanced Permissions" : "詳細権限の管理者",
    "Pagination of team folders" : "チームフォルダーのページ分割",
    "Previous" : "前へ",
    "Next" : "次へ",
    "User" : "ユーザー",
    "Unknown" : "不明",
    "Users/groups that can manage" : "管理できるユーザー/グループ",
    "None" : "なし",
    "No other groups or teams available" : "他のグループやチームはありません",
    "No other groups available" : "他のグループはありません",
    "{displayName} (team)" : "{displayName}(チーム)",
    "Add group or team" : "グループまたはチームを追加する",
    "{size} used" : "{size} を使用中",
    "Other …" : "その他 ...",
    "You can not remove your own read permission." : "自分で読み取り権限を削除することはできません。",
    "Group folders" : "グループフォルダー",
    "Admin configured folders shared with everyone in a group" : "グループ内の全員と共有する管理者設定のフォルダー",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理者が設定したフォルダをグループ全員で共有。\n\nフォルダは管理者設定の*グループフォルダ*から設定できます。\n\nフォルダが作成された後、管理者は1つまたは複数のグループにフォルダへのアクセス権を与え、書き込み/共有権限を制御し、フォルダのクォータを割り当てることができます。",
    "Group folder" : "グループフォルダー",
    "Open group folder" : "グループフォルダを開く",
    "List of group folders." : "グループフォルダのリスト",
    "No group folders yet" : "グループフォルダーはまだありません",
    "Group folders will show up here" : "グループフォルダーはここに表示されます",
    "Group folder admin delegation" : "グループフォルダー管理者の委任",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloudではグループフォルダーの管理を管理者以外のユーザーに委任することができます。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "グループフォルダーの管理とAPI/RESTの使用を許可するグループを以下に指定します。",
    "They will have access to all group folders." : "彼らはすべてのグループフォルダーにアクセスできます。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "グループフォルダーの管理とAPI/RESTのみ使用を許可するグループを以下に指定します。",
    "They will only have access to group folders for which they have advanced permissions." : "委任された人はあらかじめ許可が与えられたグループフォルダーにだけアクセスできます。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理者が設定したフォルダーをチーム全員で共有。\n\nフォルダーは管理者設定の*チームフォルダー*から設定できます。\n\nフォルダーが作成された後、管理者は1つまたは複数のチームにフォルダへのアクセス権を与え、書き込み/共有権限を制御し、フォルダーのクォータを割り当てることができます。"
},
"nplurals=1; plural=0;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/ja.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "自分で読み取り権限を削除することはできません。",
    "Team folders" : "チームフォルダー",
    "Unset" : "設定を解除",
    "Denied (Inherited permission)" : "拒否（権限継承）",
    "Allowed (Inherited permission)" : "許可（権限継承）",
    "Denied" : "拒否",
    "Allowed" : "許可",
    "Access denied" : "アクセス拒否",
    "Access allowed" : "アクセス許可",
    "Inherit permission" : "権限継承",
    "Deny" : "拒否",
    "Allow" : "許可",
    "Group" : "グループ",
    "Team" : "チーム",
    "Team folder" : "チームフォルダー",
    "Read" : "読み込み",
    "Write" : "編集",
    "Create" : "作成",
    "Delete" : "削除",
    "Share" : "共有",
    "You" : "自分",
    "Remove access rule" : "アクセスルールを削除",
    "Add advanced permission rule" : "詳細な権限ルールを追加",
    "Select a user or group" : "ユーザーまたはグループを選択",
    "Open Team folder" : "チームフォルダを開く",
    "Permission denied. User does not have sufficient permissions." : "パーミッションが拒否されました。ユーザーには十分な権限がありません。",
    "Unexpected status from server" : "サーバーからの予期しないステータス",
    "List of Team folders." : "チームフォルダーのリスト",
    "No Team folders yet" : "チームフォルダーはまだありません",
    "Team folders will show up here" : "チームフォルダーはここに表示されます",
    "Add group" : "グループを追加",
    "Default" : "デフォルト",
    "Unlimited" : "無制限",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "\"{folderName}\" とその中のすべてのファイルを削除してもよろしいですか？この操作は元に戻せません。",
    "Delete \"{folderName}\"?" : "\"{folderName}\" を削除しますか?",
    "Team folder admin delegation" : "チームフォルダー管理者の委任",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloudではチームフォルダーの管理を管理者以外のユーザーに委任することができます。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "チームフォルダーの管理とAPI/RESTの使用を許可するグループを以下に指定します。",
    "They will have access to all Team folders." : "彼らはすべてのチームフォルダーにアクセスできます。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "チームフォルダーの管理とAPI/RESTのみ使用を許可するグループを以下に指定します。",
    "They will only have access to Team folders for which they have advanced permissions." : "委任された人はあらかじめ許可が与えられたチームフォルダーにだけアクセスできます。",
    "Group or team" : "グループまたはチーム",
    "Sort by number of groups or teams that have access to this folder" : "このフォルダーにアクセスできるグループまたはチームの数で並べ替える",
    "Sort by number of groups that have access to this folder" : "このフォルダーにアクセスできるグループの数で並べ替える",
    "Folder name" : "フォルダー名",
    "Quota" : "クオータ",
    "Advanced Permissions" : "詳細権限の管理者",
    "Pagination of team folders" : "チームフォルダーのページ分割",
    "Previous" : "前へ",
    "Next" : "次へ",
    "User" : "ユーザー",
    "Unknown" : "不明",
    "Users/groups that can manage" : "管理できるユーザー/グループ",
    "None" : "なし",
    "No other groups or teams available" : "他のグループやチームはありません",
    "No other groups available" : "他のグループはありません",
    "{displayName} (team)" : "{displayName}(チーム)",
    "Add group or team" : "グループまたはチームを追加する",
    "{size} used" : "{size} を使用中",
    "Other …" : "その他 ...",
    "You can not remove your own read permission." : "自分で読み取り権限を削除することはできません。",
    "Group folders" : "グループフォルダー",
    "Admin configured folders shared with everyone in a group" : "グループ内の全員と共有する管理者設定のフォルダー",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理者が設定したフォルダをグループ全員で共有。\n\nフォルダは管理者設定の*グループフォルダ*から設定できます。\n\nフォルダが作成された後、管理者は1つまたは複数のグループにフォルダへのアクセス権を与え、書き込み/共有権限を制御し、フォルダのクォータを割り当てることができます。",
    "Group folder" : "グループフォルダー",
    "Open group folder" : "グループフォルダを開く",
    "List of group folders." : "グループフォルダのリスト",
    "No group folders yet" : "グループフォルダーはまだありません",
    "Group folders will show up here" : "グループフォルダーはここに表示されます",
    "Group folder admin delegation" : "グループフォルダー管理者の委任",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloudではグループフォルダーの管理を管理者以外のユーザーに委任することができます。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "グループフォルダーの管理とAPI/RESTの使用を許可するグループを以下に指定します。",
    "They will have access to all group folders." : "彼らはすべてのグループフォルダーにアクセスできます。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "グループフォルダーの管理とAPI/RESTのみ使用を許可するグループを以下に指定します。",
    "They will only have access to group folders for which they have advanced permissions." : "委任された人はあらかじめ許可が与えられたグループフォルダーにだけアクセスできます。",
    "Admin configured folders shared with everyone in a team" : "チーム内の全員と共有する管理者設定のフォルダー",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理者が設定したフォルダーをチーム全員で共有。\n\nフォルダーは管理者設定の*チームフォルダー*から設定できます。\n\nフォルダーが作成された後、管理者は1つまたは複数のチームにフォルダへのアクセス権を与え、書き込み/共有権限を制御し、フォルダーのクォータを割り当てることができます。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理者が設定したフォルダをチーム全員で共有。\n\nフォルダは管理者設定の*チームフォルダ*から設定できます。\n\nフォルダが作成されると、管理者は1つまたは複数のチームにフォルダへのアクセス権を与え、書き込み/共有権限を制御し、フォルダのクォータを割り当てることができます。\nHub 10/Nextcloud 31では、管理者はチームの一員でなければチームフォルダーを割り当てることができません。"
},
"nplurals=1; plural=0;");
